/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.wicketstuff.jmx.markup.html.tree.detail;

import java.util.Map;

import javax.management.ObjectName;

import org.apache.wicket.markup.html.panel.EmptyPanel;
import org.wicketstuff.jmx.markup.html.tree.DetailPanel;
import org.wicketstuff.jmx.util.JmxMBeanWrapper;

/**
 * Renders details about an {@link ObjectName} (wrapped by a
 * {@link JmxMBeanWrapper}).
 * 
 * @author Gerolf Seitz
 * 
 */
public class ObjectNameDetailPanel extends DetailPanel
{
	private static final long serialVersionUID = 1L;

	public ObjectNameDetailPanel(String id, JmxMBeanWrapper bean)
	{
		super(id);
		setOutputMarkupId(true);
		if (bean.getMBeanInfo() == null)
		{
			add(new EmptyPanel("properties"));
		}
		else
		{
			add(new NameValueTable("properties", bean)
			{
				private static final long serialVersionUID = 1L;

				@Override
				protected void populateInfoProperties(JmxMBeanWrapper bean, Map props)
				{
					props.put("ObjectName", bean.getObjectName().getDomain() + ":"
							+ bean.getObjectName().getKeyPropertyListString());
					props.put("ClassName", bean.getMBeanInfo().getClassName());
					props.put("Description", bean.getMBeanInfo().getDescription());
				}
			});
		}
	}
}
